'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.babelrc = exports.nodeHooksPath = undefined;

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _fileExists = require('file-exists');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var projectFolder = process.cwd();
var packageJsonPath = _path2.default.resolve(projectFolder, 'package.json');
var packageJson = (0, _fileExists.sync)(packageJsonPath) ? require(packageJsonPath) : {};
var pkgConfig = packageJson['babel-runner'] || {};

// Retrieve Paths for babelrc & node hooks from default locations or from package.json

var nodeHooksPath = exports.nodeHooksPath = function () {
  var filePath = pkgConfig.nodeHooks ? pkgConfig.nodeHooks : _path2.default.resolve(projectFolder, 'nodeHooks.js');
  return (0, _fileExists.sync)(filePath) ? filePath : null;
}();

var babelrc = exports.babelrc = function () {
  var defaultBabelrcJS = _path2.default.resolve(projectFolder, 'babelrc.js');
  var defaultBabelrcJson = _path2.default.resolve(projectFolder, '.babelrc');

  if ((0, _fileExists.sync)(defaultBabelrcJson)) {
    return JSON.parse(_fs2.default.readFileSync(defaultBabelrcJson, 'utf8'));
  } else if ((0, _fileExists.sync)(defaultBabelrcJS)) {
    return require(defaultBabelrcJS);
  } else if (pkgConfig.babelrc) {
    if (pkgConfig.babelrc.match('.js$')) {
      return require(pkgConfig.babelrc);
    }

    return JSON.parse(_fs2.default.readFileSync(pkgConfig.babelrc, 'utf8'));
  }

  return null;
}();

// Run babel and include node-hooks

exports.default = function () {
  var _ref = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {},
      fileToRun = _ref.fileToRun;

  // Teach Node how to import other filetypes, such as .scss .jsx or .png
  if (nodeHooksPath) {
    require(nodeHooksPath);
  }

  // Teach Node how to use babel compilation, using explicitly specified babelrc
  if (babelrc) {
    require('babel-register')(babelrc);
  }

  if (fileToRun) {
    // rely on Node error if file doesn't exist
    require(fileToRun);
  }
};